Module: Cucumber::RunningTestCase
- Defined in:
- lib/cucumber/running_test_case.rb
Overview
Represents the current status of a running test case.
This wraps a Cucumber::Core::Test::Case and delegates
many methods to that object.
We decorete the core object with the current result.
In the first Before hook of a scenario, this will be an
instance of Cucumber::Core::Test::Result::Unknown
but as the scenario runs, it will be updated to reflect
the passed / failed / undefined / skipped status of
the test case.
The test case might come from a regular Scenario or
a Scenario outline. You can call the #outline?
predicate to find out. If it's from an outline,
you get a couple of extra methods.
Defined Under Namespace
Classes: Scenario, ScenarioOutlineExample
Class Method Summary collapse
Class Method Details
.new(test_case) ⇒ Object
22 23 24 |
# File 'lib/cucumber/running_test_case.rb', line 22 def self.new(test_case) Builder.new(test_case).running_test_case end |